pickdict.core


create-dictionary-tableclj


create-file!clj

(create-file! table-name schema)
(create-file! db table-name schema)

Create a table and its associated dictionary table (Pick/D3 style)

Create a table and its associated dictionary table (Pick/D3 style)
raw docstring

create-recordclj


create-tableclj


define-dictionary-fieldclj


delete-recordclj


drop-tableclj


evaluate-clojure-expressionclj


execute-commandclj


execute-queryclj


find-allclj


find-by-idclj


table-exists?clj


translate-field-valueclj


update-recordclj

cljdoc builds & hosts documentation for Clojure/Script libraries