pickdict.crud


apply-computed-fieldsclj

(apply-computed-fields table-name record)

apply-dictionary-field-mappingclj

(apply-dictionary-field-mapping db table-name record field-attrs)

apply-dictionary-mappingsclj

(apply-dictionary-mappings db table-name record)

apply-direct-field-mappingclj

(apply-direct-field-mapping _db _table-name record {:keys [field-name]})

apply-translationsclj

(apply-translations db table-name record)

computed-fields-registryclj


create-recordclj

(create-record db table-name record)

Create a new record in a table. Returns the generated ID.

Create a new record in a table. Returns the generated ID.
raw docstring

delete-recordclj

(delete-record db table-name id)

Delete a record by ID. Returns true if successful.

Delete a record by ID. Returns true if successful.
raw docstring

dict-field->source-keyclj

(dict-field->source-key field-name)

find-by-idclj

(find-by-id db table-name id)

Find a record by ID and apply dictionary mappings.

Find a record by ID and apply dictionary mappings.
raw docstring

get-dictionary-fieldsclj

(get-dictionary-fields db table-name)

get-dictionary-table-nameclj

(get-dictionary-table-name table-name)

multiply-fieldsclj

(multiply-fields record qty-key price-key)

parse-dictionary-field-attributesclj

(parse-dictionary-field-attributes dict-field)

read-all-recordsclj

(read-all-records db table-name)

Read all records from a table and apply dictionary mappings.

Read all records from a table and apply dictionary mappings.
raw docstring

register-computed-field!clj

(register-computed-field! table-name field-name f)

Register a computed field function for a table.

Register a computed field function for a table.
raw docstring

register-translation!clj

(register-translation! table-name field-name f)

Register a translation function for a table/field.

Register a translation function for a table/field.
raw docstring

register-validator!clj

(register-validator! table-name f)

Register a validation function for a table.

Register a validation function for a table.
raw docstring

sum-multivalue-fieldclj

(sum-multivalue-field record field-key)

translation-registryclj


unregister-computed-field!clj

(unregister-computed-field! table-name field-name)

Unregister a computed field for a table.

Unregister a computed field for a table.
raw docstring

unregister-translation!clj

(unregister-translation! table-name field-name)

Unregister a translation function for a table/field.

Unregister a translation function for a table/field.
raw docstring

unregister-validator!clj

(unregister-validator! table-name)

Unregister a validation function for a table.

Unregister a validation function for a table.
raw docstring

update-recordclj

(update-record db table-name id updates)

Update a record by ID. Returns true if successful.

Update a record by ID. Returns true if successful.
raw docstring

validate-recordclj

(validate-record table-name record)

validation-registryclj

cljdoc builds & hosts documentation for Clojure/Script libraries