Dictionary operations for PickDict
Dictionary operations for PickDict
(calculate-sum-operation field-value)Calculate sum of field values
Calculate sum of field values
(create-dictionary-table db dict-name)Create a dictionary table for Pick/D3 field definitions
Create a dictionary table for Pick/D3 field definitions
(define-dictionary-field db
dict-name
field-key
field-type
position
conversion
description)Define a field in a Pick/D3 dictionary
Define a field in a Pick/D3 dictionary
(evaluate-clojure-expression expression field-values)Safely evaluate a Clojure expression in the context of record fields
Safely evaluate a Clojure expression in the context of record fields
(execute-lookup db table id)Execute a lookup query for translation fields
Execute a lookup query for translation fields
(get-all-dictionary-fields db dict-name)Get all dictionary fields for a table
Get all dictionary fields for a table
(get-dictionary-field db dict-name field-key)Get a specific dictionary field
Get a specific dictionary field
(parse-dictionary-attributes attributes-str)Parse dictionary field attributes string
Parse dictionary field attributes string
(parse-lookup-values lookup-value)Parse lookup values into a list
Parse lookup values into a list
(parse-translation-conversion conversion)Parse translation conversion string
Parse translation conversion string
(perform-lookup db table id-value)Perform a lookup for a single value
Perform a lookup for a single value
(translate-field-value db lookup-value translation-config)Translate a field value using lookup table. Always returns a vector.
Translate a field value using lookup table. Always returns a vector.
(translate-single-value db value translation-config)Translate a single value using lookup
Translate a single value using lookup
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |