(apply-computed-fields table-name record)(apply-dictionary-field-mapping db table-name record field-attrs)(apply-dictionary-mappings db table-name record)(apply-direct-field-mapping _db _table-name record {:keys [field-name]})(apply-translations db table-name record)(create-record db table-name record)Create a new record in a table. Returns the generated ID.
Create a new record in a table. Returns the generated ID.
(delete-record db table-name id)Delete a record by ID. Returns true if successful.
Delete a record by ID. Returns true if successful.
(dict-field->source-key field-name)(find-by-id db table-name id)Find a record by ID and apply dictionary mappings.
Find a record by ID and apply dictionary mappings.
(get-dictionary-fields db table-name)(get-dictionary-table-name table-name)(multiply-fields record qty-key price-key)(parse-dictionary-field-attributes dict-field)(read-all-records db table-name)Read all records from a table and apply dictionary mappings.
Read all records from a table and apply dictionary mappings.
(register-computed-field! table-name field-name f)Register a computed field function for a table.
Register a computed field function for a table.
(register-translation! table-name field-name f)Register a translation function for a table/field.
Register a translation function for a table/field.
(register-validator! table-name f)Register a validation function for a table.
Register a validation function for a table.
(sum-multivalue-field record field-key)(unregister-computed-field! table-name field-name)Unregister a computed field for a table.
Unregister a computed field for a table.
(unregister-translation! table-name field-name)Unregister a translation function for a table/field.
Unregister a translation function for a table/field.
(unregister-validator! table-name)Unregister a validation function for a table.
Unregister a validation function for a table.
(update-record db table-name id updates)Update a record by ID. Returns true if successful.
Update a record by ID. Returns true if successful.
(validate-record table-name record)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |